# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.api.agent_api import AgentApi


class TestAgentApi(unittest.TestCase):
    """AgentApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AgentApi()

    def tearDown(self) -> None:
        pass

    def test_enroll(self) -> None:
        """Test case for enroll

        """
        pass

    def test_ping(self) -> None:
        """Test case for ping

        """
        pass

    def test_remote_access(self) -> None:
        """Test case for remote_access

        """
        pass

    def test_remote_share(self) -> None:
        """Test case for remote_share

        """
        pass

    def test_remote_status(self) -> None:
        """Test case for remote_status

        """
        pass

    def test_remote_unaccess(self) -> None:
        """Test case for remote_unaccess

        """
        pass

    def test_remote_unshare(self) -> None:
        """Test case for remote_unshare

        """
        pass

    def test_share_http_healthcheck(self) -> None:
        """Test case for share_http_healthcheck

        """
        pass

    def test_unenroll(self) -> None:
        """Test case for unenroll

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.models.remote_share_request import RemoteShareRequest

class TestRemoteShareRequest(unittest.TestCase):
    """RemoteShareRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RemoteShareRequest:
        """Test RemoteShareRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RemoteShareRequest`
        """
        model = RemoteShareRequest()
        if include_optional:
            return RemoteShareRequest(
                env_zid = '',
                share_mode = 'public',
                token = '',
                target = '',
                basic_auth = [
                    ''
                    ],
                frontend_selection = [
                    ''
                    ],
                backend_mode = 'proxy',
                insecure = True,
                oauth_provider = '',
                oauth_email_address_patterns = [
                    ''
                    ],
                oauth_check_interval = '',
                open = True,
                access_grants = [
                    ''
                    ]
            )
        else:
            return RemoteShareRequest(
        )
        """

    def testRemoteShareRequest(self):
        """Test RemoteShareRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "AccountApi",
    "AdminApi",
    "AgentApi",
    "EnvironmentApi",
    "MetadataApi",
    "ShareApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "Access201Response",
    "AccessRequest",
    "AddFrontendGrantRequest",
    "AddOrganizationMemberRequest",
    "AuthUser",
    "ChangePasswordRequest",
    "ClientVersionCheckRequest",
    "Configuration",
    "CreateFrontend201Response",
    "CreateFrontendRequest",
    "CreateIdentity201Response",
    "CreateIdentityRequest",
    "CreateOrganization201Response",
    "CreateOrganizationRequest",
    "DeleteIdentityRequest",
    "DisableRequest",
    "EnableRequest",
    "Enroll200Response",
    "EnrollRequest",
    "Environment",
    "EnvironmentAndResources",
    "Frontend",
    "GetSparklines200Response",
    "GetSparklinesRequest",
    "InviteRequest",
    "InviteTokenGenerateRequest",
    "ListFrontends200ResponseInner",
    "ListMemberships200Response",
    "ListMemberships200ResponseMembershipsInner",
    "ListOrganizationMembers200Response",
    "ListOrganizationMembers200ResponseMembersInner",
    "ListOrganizations200Response",
    "ListOrganizations200ResponseOrganizationsInner",
    "ListPublicFrontendsForAccount200Response",
    "ListPublicFrontendsForAccount200ResponsePublicFrontendsInner",
    "LoginRequest",
    "Metrics",
    "MetricsSample",
    "Overview",
    "Ping200Response",
    "Principal",
    "RegenerateAccountToken200Response",
    "RegenerateAccountTokenRequest",
    "RegisterRequest",
    "RemoteAccessRequest",
    "RemoteShare200Response",
    "RemoteShareRequest",
    "RemoteStatus200Response",
    "RemoteStatus200ResponseAccessesInner",
    "RemoteStatus200ResponseSharesInner",
    "RemoteUnaccessRequest",
    "RemoteUnshareRequest",
    "RemoveOrganizationMemberRequest",
    "ResetPasswordRequest",
    "Share",
    "ShareHttpHealthcheck200Response",
    "ShareHttpHealthcheckRequest",
    "ShareRequest",
    "ShareResponse",
    "SparkDataSample",
    "UnaccessRequest",
    "UnshareRequest",
    "UpdateAccessRequest",
    "UpdateFrontendRequest",
    "UpdateShareRequest",
    "Verify200Response",
    "VerifyRequest",
    "VersionInventory200Response",
]

# import apis into sdk package
from zrok_api.api.account_api import AccountApi as AccountApi
from zrok_api.api.admin_api import AdminApi as AdminApi
from zrok_api.api.agent_api import AgentApi as AgentApi
from zrok_api.api.environment_api import EnvironmentApi as EnvironmentApi
from zrok_api.api.metadata_api import MetadataApi as MetadataApi
from zrok_api.api.share_api import ShareApi as ShareApi

# import ApiClient
from zrok_api.api_response import ApiResponse as ApiResponse
from zrok_api.api_client import ApiClient as ApiClient
from zrok_api.configuration import Configuration as Configuration
from zrok_api.exceptions import OpenApiException as OpenApiException
from zrok_api.exceptions import ApiTypeError as ApiTypeError
from zrok_api.exceptions import ApiValueError as ApiValueError
from zrok_api.exceptions import ApiKeyError as ApiKeyError
from zrok_api.exceptions import ApiAttributeError as ApiAttributeError
from zrok_api.exceptions import ApiException as ApiException

# import models into sdk package
from zrok_api.models.access201_response import Access201Response as Access201Response
from zrok_api.models.access_request import AccessRequest as AccessRequest
from zrok_api.models.add_frontend_grant_request import AddFrontendGrantRequest as AddFrontendGrantRequest
from zrok_api.models.add_organization_member_request import AddOrganizationMemberRequest as AddOrganizationMemberRequest
from zrok_api.models.auth_user import AuthUser as AuthUser
from zrok_api.models.change_password_request import ChangePasswordRequest as ChangePasswordRequest
from zrok_api.models.client_version_check_request import ClientVersionCheckRequest as ClientVersionCheckRequest
from zrok_api.models.configuration import Configuration as Configuration
from zrok_api.models.create_frontend201_response import CreateFrontend201Response as CreateFrontend201Response
from zrok_api.models.create_frontend_request import CreateFrontendRequest as CreateFrontendRequest
from zrok_api.models.create_identity201_response import CreateIdentity201Response as CreateIdentity201Response
from zrok_api.models.create_identity_request import CreateIdentityRequest as CreateIdentityRequest
from zrok_api.models.create_organization201_response import CreateOrganization201Response as CreateOrganization201Response
from zrok_api.models.create_organization_request import CreateOrganizationRequest as CreateOrganizationRequest
from zrok_api.models.delete_identity_request import DeleteIdentityRequest as DeleteIdentityRequest
from zrok_api.models.disable_request import DisableRequest as DisableRequest
from zrok_api.models.enable_request import EnableRequest as EnableRequest
from zrok_api.models.enroll200_response import Enroll200Response as Enroll200Response
from zrok_api.models.enroll_request import EnrollRequest as EnrollRequest
from zrok_api.models.environment import Environment as Environment
from zrok_api.models.environment_and_resources import EnvironmentAndResources as EnvironmentAndResources
from zrok_api.models.frontend import Frontend as Frontend
from zrok_api.models.get_sparklines200_response import GetSparklines200Response as GetSparklines200Response
from zrok_api.models.get_sparklines_request import GetSparklinesRequest as GetSparklinesRequest
from zrok_api.models.invite_request import InviteRequest as InviteRequest
from zrok_api.models.invite_token_generate_request import InviteTokenGenerateRequest as InviteTokenGenerateRequest
from zrok_api.models.list_frontends200_response_inner import ListFrontends200ResponseInner as ListFrontends200ResponseInner
from zrok_api.models.list_memberships200_response import ListMemberships200Response as ListMemberships200Response
from zrok_api.models.list_memberships200_response_memberships_inner import ListMemberships200ResponseMembershipsInner as ListMemberships200ResponseMembershipsInner
from zrok_api.models.list_organization_members200_response import ListOrganizationMembers200Response as ListOrganizationMembers200Response
from zrok_api.models.list_organization_members200_response_members_inner import ListOrganizationMembers200ResponseMembersInner as ListOrganizationMembers200ResponseMembersInner
from zrok_api.models.list_organizations200_response import ListOrganizations200Response as ListOrganizations200Response
from zrok_api.models.list_organizations200_response_organizations_inner import ListOrganizations200ResponseOrganizationsInner as ListOrganizations200ResponseOrganizationsInner
from zrok_api.models.list_public_frontends_for_account200_response import ListPublicFrontendsForAccount200Response as ListPublicFrontendsForAccount200Response
from zrok_api.models.list_public_frontends_for_account200_response_public_frontends_inner import ListPublicFrontendsForAccount200ResponsePublicFrontendsInner as ListPublicFrontendsForAccount200ResponsePublicFrontendsInner
from zrok_api.models.login_request import LoginRequest as LoginRequest
from zrok_api.models.metrics import Metrics as Metrics
from zrok_api.models.metrics_sample import MetricsSample as MetricsSample
from zrok_api.models.overview import Overview as Overview
from zrok_api.models.ping200_response import Ping200Response as Ping200Response
from zrok_api.models.principal import Principal as Principal
from zrok_api.models.regenerate_account_token200_response import RegenerateAccountToken200Response as RegenerateAccountToken200Response
from zrok_api.models.regenerate_account_token_request import RegenerateAccountTokenRequest as RegenerateAccountTokenRequest
from zrok_api.models.register_request import RegisterRequest as RegisterRequest
from zrok_api.models.remote_access_request import RemoteAccessRequest as RemoteAccessRequest
from zrok_api.models.remote_share200_response import RemoteShare200Response as RemoteShare200Response
from zrok_api.models.remote_share_request import RemoteShareRequest as RemoteShareRequest
from zrok_api.models.remote_status200_response import RemoteStatus200Response as RemoteStatus200Response
from zrok_api.models.remote_status200_response_accesses_inner import RemoteStatus200ResponseAccessesInner as RemoteStatus200ResponseAccessesInner
from zrok_api.models.remote_status200_response_shares_inner import RemoteStatus200ResponseSharesInner as RemoteStatus200ResponseSharesInner
from zrok_api.models.remote_unaccess_request import RemoteUnaccessRequest as RemoteUnaccessRequest
from zrok_api.models.remote_unshare_request import RemoteUnshareRequest as RemoteUnshareRequest
from zrok_api.models.remove_organization_member_request import RemoveOrganizationMemberRequest as RemoveOrganizationMemberRequest
from zrok_api.models.reset_password_request import ResetPasswordRequest as ResetPasswordRequest
from zrok_api.models.share import Share as Share
from zrok_api.models.share_http_healthcheck200_response import ShareHttpHealthcheck200Response as ShareHttpHealthcheck200Response
from zrok_api.models.share_http_healthcheck_request import ShareHttpHealthcheckRequest as ShareHttpHealthcheckRequest
from zrok_api.models.share_request import ShareRequest as ShareRequest
from zrok_api.models.share_response import ShareResponse as ShareResponse
from zrok_api.models.spark_data_sample import SparkDataSample as SparkDataSample
from zrok_api.models.unaccess_request import UnaccessRequest as UnaccessRequest
from zrok_api.models.unshare_request import UnshareRequest as UnshareRequest
from zrok_api.models.update_access_request import UpdateAccessRequest as UpdateAccessRequest
from zrok_api.models.update_frontend_request import UpdateFrontendRequest as UpdateFrontendRequest
from zrok_api.models.update_share_request import UpdateShareRequest as UpdateShareRequest
from zrok_api.models.verify200_response import Verify200Response as Verify200Response
from zrok_api.models.verify_request import VerifyRequest as VerifyRequest
from zrok_api.models.version_inventory200_response import VersionInventory200Response as VersionInventory200Response
